# Reacton

 * [Documentation](https://reacton.solara.dev/)
 * [GitHub](https://github.com/widgetti/reacton/)

Reacton is a React-like layer around ipywidgets.

Using a declarative way, in a React (JS) style, makes your codebase smaller, less error-prone, and easier to reason about. We don't see a good reason not to use it.

Also, React has proven itself, and by adopting a proven technology, we can stand on the shoulders of giants, make use of a lot of existing resources, and do not have to reinvent the wheel.
